==> ferite_1.0.0.1+rc2.orig.tar.gz: ferite-1.0.0.1+rc2.orig/include/ferite/fgc.h <==
/*
 * Copyright (C) 2000-2004 Chris Ross and various contributors
 * Copyright (C) 1999-2000 Chris Ross
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 * o Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * o Neither the name of the ferite software nor the names of its contributors may
 *   be used to endorse or promote products derived from this software without
 *   specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef __FERITE_GC_H__
#define __FERITE_GC_H__

FERITE_API void ferite_init_std_gc( FeriteScript *script );
FERITE_API void ferite_deinit_std_gc( FeriteScript *script );
FERITE_API void ferite_add_to_std_gc( FeriteScript *script, FeriteObject *obj );
FERITE_API void ferite_check_std_gc( FeriteScript *script );
FERITE_API void ferite_merge_std_gc( FeriteScript *script, void *g );

FERITE_API void ferite_init_generation_gc( FeriteScript *script );
FERITE_API void ferite_deinit_generation_gc( FeriteScript *script );
FERITE_API void ferite_add_to_generation_gc( FeriteScript *script, FeriteObject *obj );
FERITE_API void ferite_check_generation_gc( FeriteScript *script );
FERITE_API void ferite_check_gc_generation( FeriteScript *script, FeriteGCGeneration *g );
FERITE_API void ferite_merge_generation_gc( FeriteScript *script, void *g );

#endif /* __FERITE_GC_H__ */

==> ferite-1.1.17.tar.gz: ferite-1.1.17/include/ferite/fgc.h <==
/*
 * Copyright (C) 2000-2007 Chris Ross and various contributors
 * Copyright (C) 1999-2000 Chris Ross
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 * o Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * o Neither the name of the ferite software nor the names of its contributors may
 *   be used to endorse or promote products derived from this software without
 *   specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef __FERITE_GC_H__
#define __FERITE_GC_H__

FERITE_API void ferite_init_std_gc( FeriteScript *script );
FERITE_API void ferite_deinit_std_gc( FeriteScript *script );
FERITE_API void ferite_add_to_std_gc( FeriteScript *script, FeriteObject *obj );
FERITE_API void ferite_check_std_gc( FeriteScript *script );
FERITE_API void ferite_merge_std_gc( FeriteScript *script, void *g );

FERITE_API void ferite_init_generation_gc( FeriteScript *script );
FERITE_API void ferite_deinit_generation_gc( FeriteScript *script );
FERITE_API void ferite_add_to_generation_gc( FeriteScript *script, FeriteObject *obj );
FERITE_API void ferite_check_generation_gc( FeriteScript *script );
FERITE_API void ferite_check_gc_generation( FeriteScript *script, FeriteGCGeneration *g );
FERITE_API void ferite_merge_generation_gc( FeriteScript *script, void *g );

FERITE_API void ferite_init_libgc_gc( FeriteScript *script );
FERITE_API void ferite_deinit_libgc_gc( FeriteScript *script );
FERITE_API void ferite_add_to_libgc_gc( FeriteScript *script, FeriteObject *obj );
FERITE_API void ferite_check_libgc_gc( FeriteScript *script );
FERITE_API void ferite_merge_libgc_gc( FeriteScript *script, void *g );

#endif /* __FERITE_GC_H__ */
